@@ -4,7 +4,7 @@ Main interface for elasticache service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_elasticache import (
         CacheClusterAvailableWaiter,
         CacheClusterDeletedWaiter,
@@ -31,10 +31,8 @@ Usage::
         ReplicationGroupDeletedWaiter,
     )
 
-    session = boto3.Session()
-
-    client: ElastiCacheClient = boto3.client("elasticache")
-    session_client: ElastiCacheClient = session.client("elasticache")
+    session = Session()
+    client: ElastiCacheClient = session.client("elasticache")
 
     cache_cluster_available_waiter: CacheClusterAvailableWaiter = client.get_waiter("cache_cluster_available")
     cache_cluster_deleted_waiter: CacheClusterDeletedWaiter = client.get_waiter("cache_cluster_deleted")
